Citation
========

If you would like to cite NengoDL in your research, please cite the `white
paper <https://arxiv.org/abs/1805.11144>`_:

.. code-block:: text

  Rasmussen, D. (2018). NengoDL: Combining deep learning and neuromorphic
  modelling methods. arXiv:1805.11144, 1–22.

.. code-block:: text

  @article{
    Rasmussen2018,
    archivePrefix = {arXiv},
    arxivId = {1805.11144},
    author = {Rasmussen, Daniel},
    journal = {arXiv},
    pages = {1--22},
    title = {{NengoDL}: Combining deep learning and neuromorphic modelling
             methods},
    url = {http://arxiv.org/abs/1805.11144},
    volume = {1805.11144},
    year = {2018}
  }
